@@ -4,18 +4,8 @@ from email.mime.multipart import MIMEMultipart
 from email.mime.text import MIMEText
 from email.mime.base import MIMEBase
 from email import encoders
-import click
 
-@click.group()
-def cli():
-    pass
 
-@cli.command()
-@click.argument("from_mail_id",required=True)
-@click.argument("to_mail_ids",required=True)
-@click.argument("password",required=True)
-@click.argument("subject",required=True)
-@click.argument("body",required=True)
 def send_mail(from_mail_id, to_mail_ids, password, subject, body=None, file_paths=None):
     msg = MIMEMultipart()
     msg['From'] = from_mail_id
